@@ -3,13 +3,6 @@ import warnings
 
 from ._version import __version__
 
-from .rpc import (
-    account,
-    blockchain,
-    staking,
-    transaction
-)
-
 from .util import (
     Typgpy,
     get_gopath,
@@ -18,10 +11,6 @@ from .util import (
     json_load
 )
 
-from .logging import (
-    ControlledLogger
-)
-
 if sys.version_info.major < 3:
     warnings.simplefilter("always", DeprecationWarning)
     warnings.warn(
